@@ -438,15 +438,34 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.algebra.Calculatable#invert()
 	 */
-	@Override
 	public LispReal invert() {
 		return LispRational.newRational(1, value);
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.lang.number.NumericalRingElement#castInt()
+	 */
+	public int castInt() {
+		return value;
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.lang.number.NumericalRingElement#castLong()
+	 */
+	public long castLong() {
+		return value;
+	}
+
+	/* (non-Javadoc)
+	 * @see net.morilib.lang.number.NumericalRingElement#castInteger2()
+	 */
+	public Integer2 castInteger2() {
+		return Integer2.valueOf(value);
+	}
+
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#intFloor()
 	 */
-	@Override
 	public int intFloor() {
 		return value;
 	}
@@ -454,7 +473,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#longFloor()
 	 */
-	@Override
 	public long longFloor() {
 		return value;
 	}
@@ -462,7 +480,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#getInteger2Floor()
 	 */
-	@Override
 	public Integer2 getInteger2Floor() {
 		return Integer2.valueOf(value);
 	}
@@ -470,7 +487,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#intCeil()
 	 */
-	@Override
 	public int intCeil() {
 		return value;
 	}
@@ -478,7 +494,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#longCeil()
 	 */
-	@Override
 	public long longCeil() {
 		return value;
 	}
@@ -486,7 +501,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#getInteger2Ceil()
 	 */
-	@Override
 	public Integer2 getInteger2Ceil() {
 		return Integer2.valueOf(value);
 	}
@@ -494,7 +508,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#getRational()
 	 */
-	@Override
 	public Rational getRational() {
 		return toRational();
 	}
@@ -502,7 +515,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#floatValue()
 	 */
-	@Override
 	public float floatValue() {
 		return value;
 	}
@@ -510,7 +522,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lang.number.NumericalRingElement#doubleValue()
 	 */
-	@Override
 	public double doubleValue() {
 		return value;
 	}
@@ -518,7 +529,6 @@ implements JavaObjective {
 	/* (non-Javadoc)
 	 * @see net.morilib.lisp.Atom#toObject()
 	 */
-	@Override
 	public Object toObject() {
 		return new Integer(value);
 	}
